Welcome to NeuroLab’s documentation! — NeuroLab 0.2.2 documentation

### Navigation

- index
- modules |
- next |
- NeuroLab 0.2.2 documentation »

# Welcome to NeuroLab’s documentation!

NeuroLab - a library of basic neural networks algorithms with flexible network configurations and learning algorithms for Python. To simplify the using of the library, interface is similar to the package of Neural Network Toolbox (NNT) of MATLAB (c). The library is based on the package numpy (http://numpy.scipy.org), some learning algorithms are used scipy.optimize (http://scipy.org).

# Contents:

- Introduction
- Support neural networks types
- Install
- Examples
  - Modified network property
  - Feed Forward Multilayer Perceptron (newff)
  - Competing layer (newc)
  - Single Layer Perceptron (newp)
  - Learning Vector Quantization (newlvq)
  - Elman Recurrent network (newelm)
  - Hopfield Recurrent network (newhop)
  - Hemming Recurrent network (newhem)
- Library
  - net: Neural Networks
  - train: Train Algorithms
  - error: Error functions
  - trans: Transfer functions
  - init: Initializing functions
- Framework
  - core:

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- NeuroLab 0.2.2 documentation »